@@ -55,10 +55,12 @@ describe 'neutron::agents::ml2::ovs' do
         with_value(p[:firewall_driver])
       should contain_neutron_agent_ovs('securitygroup/enable_security_group').\
         with_value(['<SERVICE DEFAULT>'])
+      should_not contain_neutron_agent_ovs('securitygroup/permitted_ethertypes')
       should contain_neutron_agent_ovs('ovs/tunnel_bridge').with_ensure('absent')
       should contain_neutron_agent_ovs('ovs/local_ip').with_ensure('absent')
       should contain_neutron_agent_ovs('ovs/int_peer_patch_port').with_ensure('absent')
       should contain_neutron_agent_ovs('ovs/tun_peer_patch_port').with_ensure('absent')
+      should contain_neutron_agent_ovs('agent/tunnel_types').with_ensure('absent')
     end
 
     it 'installs neutron ovs agent package' do
@@ -92,6 +94,15 @@ describe 'neutron::agents::ml2::ovs' do
       end
     end
 
+    context 'when supplying permitted ethertypes' do
+      before :each do
+        params.merge!(:permitted_ethertypes => ['0x4008', '0x5'])
+      end
+      it 'should configured ethertypes' do
+        should contain_neutron_agent_ovs('securitygroup/permitted_ethertypes').with_value('0x4008,0x5')
+      end
+    end
+
     context 'when supplying a firewall driver' do
       before :each do
         params.merge!(:firewall_driver => false)
