@@ -1,8 +1,7 @@
 require 'spec_helper'
 
 describe 'neutron::policy' do
-
-  shared_examples_for 'neutron policies' do
+  shared_examples 'neutron policies' do
     let :params do
       {
         :policy_path => '/etc/neutron/policy.json',
@@ -16,13 +15,13 @@ describe 'neutron::policy' do
     end
 
     it 'set up the policies' do
-      is_expected.to contain_openstacklib__policy__base('context_is_admin').with({
+      should contain_openstacklib__policy__base('context_is_admin').with({
         :key        => 'context_is_admin',
         :value      => 'foo:bar',
         :file_user  => 'root',
         :file_group => 'neutron',
       })
-      is_expected.to contain_oslo__policy('neutron_config').with(
+      should contain_oslo__policy('neutron_config').with(
         :policy_file => '/etc/neutron/policy.json',
       )
     end
@@ -36,7 +35,7 @@ describe 'neutron::policy' do
         facts.merge!(OSDefaults.get_facts())
       end
 
-      it_configures 'neutron policies'
+      it_behaves_like 'neutron policies'
     end
   end
 end
