@@ -68,11 +68,13 @@ describe 'neutron::server' do
       should contain_service('neutron-server').with_name('neutron-server')
       should contain_neutron_config('DEFAULT/api_workers').with_value(facts[:os_workers])
       should contain_neutron_config('DEFAULT/rpc_workers').with_value(facts[:os_workers])
+      should contain_neutron_config('DEFAULT/rpc_response_max_timeout').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('DEFAULT/agent_down_time').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('DEFAULT/enable_new_agents').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('DEFAULT/router_scheduler_driver').with_value(p[:router_scheduler_driver])
       should contain_oslo__middleware('neutron_config').with(
         :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
+        :max_request_body_size        => '<SERVICE DEFAULT>',
       )
       should contain_neutron_config('DEFAULT/ovs_integration_bridge').with_value('<SERVICE DEFAULT>')
     end
@@ -210,6 +212,16 @@ describe 'neutron::server' do
       )}
     end
 
+    context 'with max_request_body_size' do
+      before :each do
+        params.merge!( :max_request_body_size => '102400' )
+      end
+
+      it { should contain_oslo__middleware('neutron_config').with(
+        :max_request_body_size => '102400',
+      )}
+    end
+
     context 'when running neutron-api in wsgi' do
       before :each do
         params.merge!( :service_name => 'httpd' )
@@ -294,28 +306,6 @@ describe 'neutron::server' do
     end
   end
 
-  shared_examples 'neutron server lbaas on Debian' do
-    before do
-      params.merge!( :ensure_lbaas_package => true )
-    end
-
-    it 'should install lbaas package' do
-      should contain_package('neutron-lbaas')
-      should_not contain_package('neutron-lbaasv2-agent')
-    end
-  end
-
-  shared_examples 'neutron server lbaas on RedHat' do
-    before do
-      params.merge!( :ensure_lbaas_package => true )
-    end
-
-    it 'should install lbaasv2-agent package' do
-      should_not contain_package('neutron-lbaas')
-      should contain_package('neutron-lbaasv2-agent')
-    end
-  end
-
   shared_examples 'a neutron server without database synchronization' do
     before do
       params.merge!(
@@ -353,7 +343,6 @@ describe 'neutron::server' do
       it_behaves_like 'a neutron server'
       it_behaves_like 'a neutron server without database synchronization'
       it_behaves_like "neutron server dynamic routing on #{facts[:osfamily]}"
-      it_behaves_like "neutron server lbaas on #{facts[:osfamily]}"
     end
   end
 end
